import { BlankNode, DatasetCore, Literal, NamedNode, BaseQuad, Term, Variable, DataFactory } from '@rdfjs/types';
import type { Environment } from '@rdfjs/environment/Environment.js';
import type { TermMapFactory } from '@rdfjs/term-map/Factory.js';
import { Value } from './value.js';
interface Options {
    env: Environment<DataFactory | TermMapFactory>;
}
type TagFunction<TImpl extends TemplateResult<TOptions>, TValue extends Value<TImpl>, TOptions extends Options> = {
    (strings: TemplateStringsArray, ...values: TValue[]): TImpl;
};
export interface PartialString {
    value: string;
    prefixes: Iterable<string>;
}
export declare abstract class SerializationStrategy<TOptions> {
    abstract evaluateLiteral(term: Literal, options: TOptions): PartialString;
    abstract evaluateNamedNode(term: NamedNode, options: TOptions): PartialString;
    abstract evaluateVariable(term: Variable, options: TOptions): PartialString;
    abstract evaluateBlankNode(term: BlankNode, options: TOptions): PartialString;
    abstract evaluateQuad(quad: BaseQuad, options: TOptions): PartialString;
    abstract evaluateDataset(dataset: DatasetCore, options: TOptions): PartialString;
    abstract getFinalString(result: string, prefixes: Iterable<string>, options: TOptions): string;
    evaluateTerm(value: Term, options: TOptions): PartialString;
}
export interface TemplateResultInit<TOptions extends Options> {
    strings: TemplateStringsArray;
    values: Value<TemplateResult<TOptions>>[];
    tag: TagFunction<any, Value<any>, TOptions>;
    strategy: SerializationStrategy<TOptions>;
    defaultOptions(env: TOptions['env']): Omit<TOptions, 'env'>;
}
export declare class TemplateResult<TOptions extends Options> {
    protected readonly strings: TemplateStringsArray;
    protected readonly values: readonly (Value<TemplateResult<TOptions>> | object)[];
    protected readonly _tag: TagFunction<TemplateResult<TOptions>, Value<TemplateResult<TOptions>>, TOptions>;
    private readonly __strategy;
    private readonly __defaultOptions;
    constructor({ strings, values, tag, strategy, defaultOptions, }: TemplateResultInit<TOptions>);
    toString({ env, ...options }?: Partial<TOptions>): string;
    _toPartialString(options: TOptions): PartialString;
}
export {};
//# sourceMappingURL=TemplateResult.d.ts.map